---
name: Feature Request
about: Create a feature request for a functionality that does not currently exist in the ONNX.
title: ''
labels: 'enhancement'
assignees: ''

 

---
# Feature Request

### System information
ONNX version (you are using):

### What is the problem that this feature solves?
Please detail the discrepancy with our current functionality.

### Describe the alternatives you have considered
A clear and concise description of any alternative solutions or features you've considered

### Describe the feature
Why is this feature necessary? What does it accomplish?

### Will this influence the current api?
If yes, how? 

### Feature Area
Which area in ONNX does this impact?  (*e.g. model usage, backend, best practices, converters, shape_inference, version_converter, training, test, operators*): 

### Are you willing to contribute it (Y/N):

### Notes
Any additional information
